ml4gw.nn.resnet package
=======================

Submodules
----------

ml4gw.nn.resnet.resnet\_1d module
---------------------------------

.. automodule:: ml4gw.nn.resnet.resnet_1d
   :members:
   :undoc-members:
   :show-inheritance:

ml4gw.nn.resnet.resnet\_2d module
---------------------------------

.. automodule:: ml4gw.nn.resnet.resnet_2d
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: ml4gw.nn.resnet
   :members:
   :undoc-members:
   :show-inheritance:
